# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .task_response import TaskResponse as TaskResponse
from .topic_response import TopicResponse as TopicResponse
from .run_list_params import RunListParams as RunListParams
from .task_list_params import TaskListParams as TaskListParams
from .test_list_params import TestListParams as TestListParams
from .document_response import DocumentResponse as DocumentResponse
from .run_list_response import RunListResponse as RunListResponse
from .topic_list_params import TopicListParams as TopicListParams
from .trace_list_params import TraceListParams as TraceListParams
from .task_create_params import TaskCreateParams as TaskCreateParams
from .task_list_response import TaskListResponse as TaskListResponse
from .test_list_response import TestListResponse as TestListResponse
from .annotation_response import AnnotationResponse as AnnotationResponse
from .task_trigger_params import TaskTriggerParams as TaskTriggerParams
from .topic_create_params import TopicCreateParams as TopicCreateParams
from .topic_list_response import TopicListResponse as TopicListResponse
from .trace_list_response import TraceListResponse as TraceListResponse
from .application_response import ApplicationResponse as ApplicationResponse
from .document_list_params import DocumentListParams as DocumentListParams
from .ingest_create_params import IngestCreateParams as IngestCreateParams
from .style_guide_response import StyleGuideResponse as StyleGuideResponse
from .run_retrieve_response import RunRetrieveResponse as RunRetrieveResponse
from .annotation_list_params import AnnotationListParams as AnnotationListParams
from .document_create_params import DocumentCreateParams as DocumentCreateParams
from .document_list_response import DocumentListResponse as DocumentListResponse
from .ingest_create_response import IngestCreateResponse as IngestCreateResponse
from .test_retrieve_response import TestRetrieveResponse as TestRetrieveResponse
from .application_list_params import ApplicationListParams as ApplicationListParams
from .style_guide_list_params import StyleGuideListParams as StyleGuideListParams
from .trace_retrieve_response import TraceRetrieveResponse as TraceRetrieveResponse
from .annotation_create_params import AnnotationCreateParams as AnnotationCreateParams
from .annotation_list_response import AnnotationListResponse as AnnotationListResponse
from .application_create_params import ApplicationCreateParams as ApplicationCreateParams
from .application_list_response import ApplicationListResponse as ApplicationListResponse
from .style_guide_create_params import StyleGuideCreateParams as StyleGuideCreateParams
from .style_guide_list_response import StyleGuideListResponse as StyleGuideListResponse
from .document_list_chunks_params import DocumentListChunksParams as DocumentListChunksParams
from .document_list_chunks_response import DocumentListChunksResponse as DocumentListChunksResponse
from .validate_webhook_validate_params import ValidateWebhookValidateParams as ValidateWebhookValidateParams
from .validate_webhook_validate_response import ValidateWebhookValidateResponse as ValidateWebhookValidateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["AnnotationCreateParams"]


class AnnotationCreateParams(TypedDict, total=False):
    title: Required[str]
    """Title of the annotation"""

    created_at: Annotated[Union[str, datetime], PropertyInfo(alias="createdAt", format="iso8601")]
    """Custom creation date for the annotation (ISO8601 format)"""

    description: Optional[str]
    """A description of what was changed in the application configuration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["ApplicationCreateParams"]


class ApplicationCreateParams(TypedDict, total=False):
    slug: Required[str]
    """URL-friendly slug for the application"""

    title: Required[str]
    """Title of the application"""

    type: Required[Literal["CHATBOT", "AGENT"]]
    """Type of the application"""

    context: str
    """Context/instructions for the application"""

    description: str
    """Description of the application"""

    environment: Literal["DEV", "PROD"]
    """Environment of the application"""
